@@ -17,7 +17,7 @@ import os, datetime
 import hashlib
 from collections import deque
 
-VERSION = "1.2.0"
+VERSION = "1.2.1"
 
 ###############################################################
 class idict(object):
@@ -266,6 +266,7 @@ class node(object):
     self.paths_set = set() 
     # None means TBD by graph walk. 
     # Otherwise 0 is uptodate, 1 means needs refresh.
+    # If file doesn't exist, then update() will set stale to true.
     self.stale = None
     # Missing files will always by older relative to real files.
     self.time = 0
@@ -332,7 +333,12 @@ class node(object):
   def update(self, time=True, hash=False):
     """Get modified time for file from system and optionally compute hash."""
     self.stale = None
-    if time and os.path.exists(self.name):
+    exists = os.path.exists(self.name)
+    
+    # Missing file is considered stale (we need to make it).
+    if not exists: self.stale = 1
+    
+    if time and exists:
       self.time = os.path.getmtime(self.name)
 
     if hash: self.hash = hashdb.md5(self.name)
